@@ -5,6 +5,7 @@
 import weakref
 from collections import deque, namedtuple
 from functools import partial
+from contextlib import suppress
 
 from .borders import Borders
 from .child import Child
@@ -28,10 +29,8 @@ def SpecialWindow(cmd, stdin=None, override_title=None, cwd_from=None, cwd=None,
 
 
 def add_active_id_to_history(items, item_id, maxlen=64):
-    try:
+    with suppress(ValueError):
         items.remove(item_id)
-    except ValueError:
-        pass
     items.append(item_id)
     if len(items) > maxlen:
         items.popleft()
@@ -223,7 +222,7 @@ class Tab:  # {{{
         if env:
             fenv.update(env)
         fenv['KITTY_WINDOW_ID'] = str(next_window_id())
-        if not is_macos and not is_wayland:
+        if not is_macos and not is_wayland():
             try:
                 fenv['WINDOWID'] = str(x11_window_id(self.os_window_id))
             except Exception:
@@ -233,7 +232,7 @@ class Tab:  # {{{
         ans.fork()
         return ans
 
-    def new_window(self, use_shell=True, cmd=None, stdin=None, override_title=None, cwd_from=None, cwd=None, overlay_for=None, env=None):
+    def new_window(self, use_shell=True, cmd=None, stdin=None, override_title=None, cwd_from=None, cwd=None, overlay_for=None, env=None, location=None):
         child = self.launch_child(use_shell=use_shell, cmd=cmd, stdin=stdin, cwd_from=cwd_from, cwd=cwd, env=env)
         window = Window(self, child, self.opts, self.args, override_title=override_title)
         if overlay_for is not None:
@@ -242,12 +241,12 @@ class Tab:  # {{{
             overlaid.overlay_window_id = window.id
         # Must add child before laying out so that resize_pty succeeds
         get_boss().add_child(window)
-        self.active_window_idx = self.current_layout.add_window(self.windows, window, self.active_window_idx)
+        self.active_window_idx = self.current_layout.add_window(self.windows, window, self.active_window_idx, location)
         self.relayout_borders()
         return window
 
-    def new_special_window(self, special_window):
-        return self.new_window(False, *special_window)
+    def new_special_window(self, special_window, location=None):
+        return self.new_window(False, *special_window, location=location)
 
     def close_window(self):
         if self.windows:
@@ -269,6 +268,12 @@ class Tab:  # {{{
             next_window_id = self.windows[idx].id
         active_window_idx = self.current_layout.remove_window(self.windows, window, self.active_window_idx)
         remove_window(self.os_window_id, self.id, window.id)
+        if window.overlay_for is not None:
+            for idx, q in enumerate(self.windows):
+                if q.id == window.overlay_for:
+                    active_window_idx = idx
+                    next_window_id = q.id
+                    break
         if next_window_id is None and active_window_idx is not None and len(self.windows) > active_window_idx:
             next_window_id = self.windows[active_window_idx].id
         if next_window_id is not None:
@@ -473,15 +478,16 @@ class TabManager:  # {{{
         try:
             idx = self.tabs.index(tab)
         except Exception:
-            return
+            return False
         self.set_active_tab_idx(idx)
+        return True
 
     def next_tab(self, delta=1):
         if len(self.tabs) > 1:
             self.set_active_tab_idx((self.active_tab_idx + len(self.tabs) + delta) % len(self.tabs))
 
     def goto_tab(self, tab_num):
-        if tab_num < len(self.tabs) and 0 <= tab_num:
+        if 0 <= tab_num < len(self.tabs):
             self.set_active_tab_idx(tab_num)
         elif tab_num < 0:
             try:
